@@ -38,8 +38,6 @@ report.sessionInfo <- function(x, ...) {
 
 
 
-
-
 # Aliases -----------------------------------------------------------------
 
 
@@ -52,7 +50,6 @@ report_packages <- function(session = NULL, include_R = TRUE, ...) {
 }
 
 
-
 #' @importFrom utils sessionInfo
 #' @rdname report.sessionInfo
 #' @export
@@ -73,7 +70,6 @@ cite_packages <- function(session = NULL, include_R = TRUE, ...) {
 
 
 
-
 # report_system --------------------------------------------------------------
 
 
@@ -173,12 +169,8 @@ report_parameters.sessionInfo <- function(x, table = NULL, include_R = TRUE, ...
     format_citation(x$Reference, authorsdate = TRUE, short = TRUE, intext = TRUE),
     ")"
   )
-  x$summary <- paste0(
-    x$Package,
-    " (v",
-    x$Version,
-    ")"
-  )
+
+  x$summary <- paste0(x$Package, " (v", x$Version, ")")
 
   x <- x[order(x$Reference), ]
 
